Deterministic password generation.
Ciranda derives the same password from the same seed, context, password settings, and Argon2 settings.
Start with enhance for the main API.
Structs
- Argon2
Settings - Character
Sets - Character groups available to the deterministic password-construction stage.
- Password
Settings - Password construction settings.
Enums
- Argon2
Profile - Named Argon2id presets for common use cases.
- Character
Set - A single selectable password character group.
Constants
Functions
- enhance
- Derives a password from a seed and context using Argon2id KDF and BLAKE3 hashing.